
/***
UHS2008
***/

*work directory
use "$myPath/data/2008p.dta",clear
tostring dcode hcode ,replace
generate dhcode = dcode + "0000" if strlen(hcode) == 1 
replace dhcode = dcode + "000" if strlen(hcode) == 2
replace dhcode = dcode + "00" if strlen(hcode) == 3
replace dhcode = dcode + "0" if strlen(hcode) == 4
replace dhcode = dcode  if strlen(hcode) == 5
replace dhcode = dhcode + hcode

order hcode year, after(dcode)


drop if a1 == 99


generate birth = 0
replace birth = a7 if a1 == 1
label variable birth "户主出生年月"
tostring birth ,replace

generate birth_year = 0
tostring birth_year ,replace
replace birth_year = substr(birth,1,4)  if a1 == 1 & a7 != 0
destring birth_year , replace
label variable birth_year "户主出生年份"


generate birth_month = 0
tostring birth_month ,replace
replace birth_month = substr(birth,-2,2)  if a1 == 1 & a7 != 0
destring birth_month birth, replace
label variable birth_month "户主出生月份"

bysort dhcode: egen birth_month_max = max(birth_month)
bysort dhcode: egen birth_year_max = max(birth_year)
bysort dhcode: egen birth_max = max(birth)
replace birth = birth_max
replace birth_month = birth_month_max
replace birth_year = birth_year_max

generate age = .
replace age = 2008 - birth_year if !missing(birth_year) & birth_year>0
label variable age "户主的年龄"

generate retire = 0
replace retire =1 if a1541 > 0 & a1 == 1  
bysort dhcode: egen retire_max = max(retire)
replace retire = retire_max
label variable retire "离退休家庭"

generate coresid = 0
replace coresid = 1 if a2 == 3 | a2 == 8
bysort dhcode: egen child_coresid = max(coresid)
label variable child_coresid "是否有子女/孙辈与老年人同住"
label value child_coresid dummy

bysort dhcode: egen child_coresid_num = sum(child_coresid)
label variable child_coresid_num "老年人同住子女及孙辈数量"

generate unemployed = 0 
replace unemployed = 1 if a12 == 13
bysort dhcode: egen unemployed_max = max(unemployed)
replace unemployed = unemployed_max
label variable unemployed "家庭中是否有失业人员"
bysort dhcode: egen unemployed_num = sum(unemployed)
label variable unemployed_num "家庭失业人员数量"

generate hukou = 0 
replace hukou = 1 if a3 == 1 | a3 ==3 
bysort dhcode: egen hukou_max = max(hukou)
replace hukou = hukou_max
label variable hukou "是否为城镇户口"

generate education = 0
label variable education "受教育水平（老年人）"
replace education = 1 if inrange(a8, 1, 2) & inrange(a2,1,2)
replace education = 2 if a8 == 3 & inrange(a2,1,2)
replace education = 3 if a8 == 4 & inrange(a2,1,2)
replace education = 4 if inrange(a8, 5, 6) & inrange(a2,1,2)
replace education = 5 if a8 == 7 & inrange(a2,1,2)
replace education = 6 if a8 == 8 & inrange(a2,1,2)
replace education = 7 if a8 == 9 & inrange(a2,1,2)
label define education  1 "文盲/半文盲" 2 "小学毕业" 3 "初中毕业" 4 "高中/中专毕业" 5 "大专毕业" 6 "大学本科毕业" 7 "研究生毕业"
label value education education
bysort dhcode: egen education_max = max(education)
replace education = education_max

generate marriage = 0 
replace marriage = 1 if a1 == 1 & a9 ==2 
bysort dhcode: egen marriage_max = max(marriage)
replace marriage = marriage_max
label variable marriage "现在是否有配偶"
label define marriage 0 "否" 1 "是"
label value marriage marriage

generate public_employee = 0
replace public_employee = 1 if inrange(a12,1,2) & inrange(a2,1,2)
bysort dhcode: egen public_employee_max = max(public_employee)
replace public_employee = public_employee_max
label variable public_employee "户主或其配偶是否为国有/集体企业员工"
label define public_employee 0 "否" 1 "是"
label value public_employee public_employee

generate soe_employee = 0
replace soe_employee = 1 if a12 == 1 & inrange(a2,1,2)
bysort dhcode: egen soe_employee_max = max(soe_employee)
replace soe_employee = soe_employee_max
label variable soe_employee "户主或其配偶是否为国有企业员工"
label define soe_employee 0 "否" 1 "是"

duplicates drop dhcode ,force 
drop qs1 - a9 unemployed_max birth_month_max birth_year_max hukou_max education_max retire_max birth_max marriage_max coresid public_employee_max soe_employee_max

save "$myPath/data/basic_2008.dta",replace
clear


use "$myPath/data/2008h.dta",clear
tostring dcode hcode ,replace
generate dhcode = dcode + "0000" if strlen(hcode) == 1 
replace dhcode = dcode + "000" if strlen(hcode) == 2
replace dhcode = dcode + "00" if strlen(hcode) == 3
replace dhcode = dcode + "0" if strlen(hcode) == 4
replace dhcode = dcode  if strlen(hcode) == 5
replace dhcode = dhcode + hcode

merge m:1 dhcode using "$myPath/data/basic_2008.dta"
drop _merge


generate hhmember = b21
label variable hhmember "家户人口数"
duplicates drop dhcode ,force 

generate labor_ratio = b311/(b311+b312)
label variable labor_ratio "家庭劳动力人口比例"

generate total_income = d92
label variable total_income "家庭总收入"

generate disposable_income = d920
label variable disposable_income "家庭可支配收入"

generate wage = d921
label variable wage "工资性收入"

generate business = d922
label variable business "家庭经营净收入"

generate property = d923
label variable property "家庭财产性收入"

generate property_l = d9231 + d9232 + d9233 + d9234 
label variable property "家庭流动性财产收入"

generate interest_received = d9231
label variable interest_received "家庭利息收入"

generate transfer = d924
label variable transfer "家庭转移性收入"

generate housing_fund = d9249
label variable housing_fund "家庭提取住房公积金金额"


generate purchase = 0
replace purchase = 1 if b211 >0
label define purchase 0 "否" 1 "是"
label variable purchase "家庭是否买房"
label value purchase dummy

generate purchase_t = b211
label variable purchase_t "家庭购房时间"

generate purchase_payment = b212    
label variable purchase_payment "家庭购房金额"
generate purchase_payment_r = b2120    
label variable purchase_payment_r "家庭实际购房金额"

generate housing_value  = b28 
label variable housing_value "家庭现住房市场价值估值"

generate purchase_t0 = 0
replace purchase_t0 = 1 if purchase_t == 2008 | d9521 >0
label define purchase_t0 0 "否" 1 "是"
label variable purchase_t0 "家庭本年是否购房"

generate purchase_payment_t0 = d9521   
label variable purchase_payment_t0 "家庭本年购房金额"

generate house_sell_t0 = d931    
label variable house_sell_t0 "家庭本年出售住房收入"

generate mortgage = 0  
replace mortgage = 1  if d967 >0
label variable mortgage "家庭是否有房贷" 
label define dummy 0 "否" 1 "是"
label value mortgage dummy

generate borrowing = .
replace borrowing = d942 
label variable borrowing "家庭借入款金额"

generate mortgage_receive = .
replace mortgage_receive = d947 
label variable mortgage_receive "家庭得到住房贷款金额"

generate auto_receive = .
replace auto_receive = d948 
label variable auto_receive "家庭得到汽车贷款金额"

generate edu_receive = .
replace edu_receive = d949 
label variable edu_receive "家庭得到教育贷款金额"

generate other_receive = .
replace other_receive = d9410 
label variable other_receive "家庭得到其他贷款金额"

generate other_borrowing = .
replace other_borrowing = d9411 
label variable other_borrowing "家庭得到其他借贷收入金额"

generate LTV = (b212 - b2120)/b212    
replace LTV = mortgage_receive/purchase_payment_t0 if missing(LTV) & !missing(mortgage_receive) & !missing(purchase_payment_t0) & purchase_payment_t0 >0 

generate mortgage_payment = d967
label variable mortgage_payment "家庭归还住房贷款金额(本金)"

generate interest_payment = d9541
label variable interest_payment "家庭归还贷款金额(利息)"

generate total_payment = interest_payment + mortgage_payment 
label variable total_payment "家庭归还住房贷款本息和"

generate loan_payment = d967 + d968 + d969 + d9610 
label variable loan_payment "家庭归还借款/贷款支出"

gen nonmortgage_payment = d968 + d969 + d9610 
label variable nonmortgage_payment "家庭归还非住房贷款金额"

gen auto_loan = d968
label variable auto_loan "家庭归还汽车贷款金额"

gen other_loan = d969 + d9610
label variable other_loan "家庭归还其他贷款金额"

generate leverage_ratio = loan_payment/disposable_income
label variable leverage_ratio "家庭杠杆率"

generate LAI = d941 + d943 + d944 + d945 + d946
label variable LAI "家庭流动性借贷资产收入"

generate loan_revenue = d94 - LAI
label variable loan_revenue "家庭借贷收入"

generate house_area = b22
label variable house_area "家庭房屋面积（平方米）"

gen owner = 1
replace owner = 0 if b24 == 1 | b24 == 2
label variable owner "家庭是住房拥有者还是租房者" 
label define owner 0 "否" 1 "是"
label value owner owner

gen house_type = . 
label variable house_type "家庭住房类型"
replace house_type = 1 if b24 == 3
replace house_type = 2 if b24 == 4
replace house_type = 3 if b24 == 5
replace house_type = 4 if b24 == 6
label define house_type  1 "原有私房" 2 "房改私房" 3 "商品房" 4 "其他类型"
label value house_type house_type

generate rent_payment = .
replace rent_payment = b29 if b29>0 & !missing(b29) & owner == 0
label variable rent_payment "家庭每月房租（元）"

gen multi_house = 0
replace multi_house = 1 if b219 > 0 
label variable multi_house "家庭是否拥有多套房产" 
label define multi_house 0 "否" 1 "是"
label value multi_house multi_house owner

generate total_house = 0 
replace total_house = b219 + 1 if owner == 1
label variable total_house "家庭拥有房产数量（套）"



gen total_consumption = e
label variable total_consumption "家庭年总消费支出"

gen service = e0
label variable service "家庭年服务性消费支出"

generate food = e1
label variable food "家庭年食品酒水支出"

generate food_out = e192
label variable food_out "家庭年食品支出(在外)"

generate food_s = e19
label variable food_s "家庭年饮食服务支出"

generate nondurables = 0
replace nondurables = nondurables + f2  

gen cloth = f2
gen cloth_s = f25
label variable cloth_s "家庭年衣着服务支出"

replace nondurables = nondurables + f5 - f511 - f521 

gen transport = f51 - f511
gen communication = f52 - f521

gen transport_s = f513 + f514
gen communication_s = f522
label variable transport_s "家庭年交通服务支出"
label variable communication_s "家庭年通信服务支出"

replace nondurables = nondurables + f7  

gen house_non = f7

replace nondurables = nondurables + (f8 -f811 - f812_2)  

gen other_s = f8 -f811 - f812_2

generate rent = f711 

generate reside_s = f73 + f36 
label variable reside_s "家庭年居住/家庭服务支出"

replace nondurables = nondurables + food + f62 
replace nondurables = nondurables + f36 

generate house_s = f36

label variable nondurables "家庭非耐用品消费"
label variable cloth "家庭衣着消费支出"
label variable transport "家庭交通消费支出"
label variable communication "家庭通信消费支出"

generate durables = f511 + f521 + f61 + (f3- f36) + (f811 + f812_2)   //
label variable durables "家庭耐用品消费"

generate edu_expense = f63
label variable edu_expense "家庭教育培训支出"

generate edu_expense_s = f632
label variable edu_expense_s "家庭教育费用支出"


generate med_expense = f4
label variable med_expense "家庭医疗保健支出"

generate med_expense_s = f45
label variable med_expense_s "家庭医疗费支出"


generate work_expense = 0
replace work_expense = work_expense + food_out  
replace work_expense = work_expense + f2   
replace work_expense = work_expense + f5144 + f5145  
label variable work_expense "家庭与工作相关支出"


generate civic_expense = f62
label variable civic_expense "家庭文娱支出"


generate other_service = f82
label variable other_service "家庭其他服务支出"


generate contribution = d9532
label variable contribution "家庭现金捐赠支出"


generate premium = d9535
label variable premium "家庭非储蓄性保险支出"


generate saving = 0
replace saving = saving + d961 - d941  
replace saving = saving + d964   
label variable saving  "家庭储蓄性支出"
gen saving1 = d961 + d964
gen saving2 = d941


generate invest1 = 0
replace invest1 = invest1 + d965  + d966  
label variable invest1  "家庭投资性支出"

generate invest2 = 0
replace invest2 = invest2 + d945  + d946  
label variable invest2  "家庭投资回收"


bysort dcode: egen med_expense_mean = mean(med_expense)
gen health = med_expense/med_expense_mean
label variable health  "家庭健康状况"


generate pension_r = 0
replace pension_r = 1 if d9241>0
label variable pension_r  "家庭是否领取养老金或离退休金"

generate pension_p = 0
replace pension_p = 1 if d9551>0
label variable pension_p  "家庭是否有养老基金支出"

generate med_p = 0
replace med_p = 1 if d9553>0
label variable med_p  "家庭是否有医疗基金支出"

keep hcode year dcode - med_p
drop med_expense_mean
save "$myPath/data/data_2008.dta",replace
clear






