********************************************************************************
* This code reproduces Table 3 in 
* Cao, J., Cui, C., Dinger, V., Holm, M.B., and Kang, S. (forthcoming). 
* Identifying the Depreciation Rate of Durables from Marginal Spending Responses. 
* Journal of Money, Credit and Banking. 
********************************************************************************


use "$myPath/data/estimation_sample.dta",clear


cap log close
log using $myPath/estimation.log, replace


* calibration
global eps = 1
* from paper
global g = -0.0427
global adjustment = ${eps}*${g}



********************************************************************************
* GMM


/*** no controls***/
gmm 			(eq1: dtotCons - {b1}*ddisposable_income - {xb:  _cons})  ///
				(eq2: dnondurables - {c1}*ddisposable_income - {xc:  _cons})  ///
                (eq3: ddurables - {d1}*ddisposable_income - {xd:  _cons})  ///
                (eq4: ndconsShare2008 - {e0}),  ///
                instruments(eq1 eq2 eq3: dy)  ///
                onestep winitial(unadjusted, indep) vce(cluster prov)


nlcom [b1]_cons
nlcom [c1]_cons
nlcom [c1]_cons/[b1]_cons
nlcom [d1]_cons
nlcom [d1]_cons/[b1]_cons
nlcom ((1-[e0]_cons)/[e0]_cons)/((1-[c1]_cons/[b1]_cons)/([c1]_cons/[b1]_cons)) + ${adjustment}*[e0]_cons
qui ivreg2 dtotCons (ddisposable_income = dy), robust cluster(prov) ffirst
display e(first)[4,1]

/***only i.prov***/
gmm (eq1: dtotCons - {b1}*ddisposable_income - {xb: _cons i.prov})  ///
                (eq2: dnondurables - {c1}*ddisposable_income - {xc: i.prov _cons})  ///
                (eq3: ddurables - {d1}*ddisposable_income - {xd: i.prov _cons})  ///
                (eq4: ndconsShare2008 - {e0}),  ///
                instruments(eq1 eq2 eq3: dy i.prov)  ///
                onestep winitial(unadjusted, indep) vce(cluster prov)


nlcom [b1]_cons
nlcom [c1]_cons
nlcom [c1]_cons/[b1]_cons
nlcom [d1]_cons
nlcom [d1]_cons/[b1]_cons
nlcom ((1-[e0]_cons)/[e0]_cons)/((1-[c1]_cons/[b1]_cons)/([c1]_cons/[b1]_cons)) + ${adjustment}*[e0]_cons
qui ivreg2 dtotCons (ddisposable_income = dy) i.prov, partial(i.prov) robust cluster(prov) ffirst
display e(first)[4,1]




/*** controls, but no municipality fixed effect***/
gmm (eq1: dtotCons - {b1}*ddisposable_income - {xb: hv_inc hhmember age age_square i.education  soe_employee _cons})  ///
                (eq2: dnondurables - {c1}*ddisposable_income - {xc: hv_inc hhmember age age_square i.education  soe_employee _cons})  ///
                (eq3: ddurables - {d1}*ddisposable_income - {xd: hv_inc hhmember age age_square i.education  soe_employee _cons})  ///
                (eq4: ndconsShare2008 - {e0}),  ///
                instruments(eq1 eq2 eq3: dy hv_inc hhmember age age_square education i.education soe_employee  )  ///
                onestep winitial(unadjusted, indep) vce(cluster prov)


nlcom [b1]_cons
nlcom [c1]_cons
nlcom [c1]_cons/[b1]_cons
nlcom [d1]_cons
nlcom [d1]_cons/[b1]_cons
nlcom ((1-[e0]_cons)/[e0]_cons)/((1-[c1]_cons/[b1]_cons)/([c1]_cons/[b1]_cons)) + ${adjustment}*[e0]_cons
qui ivreg2 dtotCons (ddisposable_income = dy) hv_inc hhmember age age_square i.education  soe_employee i.prov, partial(hv_inc hhmember age age_square i.education  soe_employee i.prov) robust cluster(prov) ffirst
display e(first)[4,1]



/*** benchmark ***/
gmm (eq1: dtotCons - {b1}*ddisposable_income - {xb: hv_inc hhmember age age_square i.education  i.prov soe_employee _cons})  ///
                (eq2: dnondurables - {c1}*ddisposable_income - {xc: hv_inc hhmember age age_square i.education  i.prov soe_employee _cons})  ///
                (eq3: ddurables - {d1}*ddisposable_income - {xd: hv_inc hhmember age age_square i.education  i.prov soe_employee _cons})  ///
                (eq4: ndconsShare2008 - {e0}),  ///
                instruments(eq1 eq2 eq3: dy i.prov hv_inc hhmember age age_square education i.education  soe_employee)  ///
                onestep winitial(unadjusted, indep) vce(cluster prov)

nlcom [b1]_cons
nlcom [c1]_cons
nlcom [c1]_cons/[b1]_cons
nlcom [d1]_cons
nlcom [d1]_cons/[b1]_cons
nlcom ((1-[e0]_cons)/[e0]_cons)/((1-[c1]_cons/[b1]_cons)/([c1]_cons/[b1]_cons)) + ${adjustment}*[e0]_cons
qui ivreg2 dtotCons (ddisposable_income = dy) hv_inc hhmember age age_square i.education  soe_employee i.prov, partial(hv_inc hhmember age age_square i.education  soe_employee i.prov) robust cluster(prov) ffirst
display e(first)[4,1]

log close

