********************************************************************************
* This code performs the sample selection in 
* Cao, J., Cui, C., Dinger, V., Holm, M.B., and Kang, S. (forthcoming). 
* Identifying the Depreciation Rate of Durables from Marginal Spending Responses. 
* Journal of Money, Credit and Banking. 
********************************************************************************

** open txt file and save as dta file
import delimited "$myPath/data/data_08-09.txt", clear 
save "$myPath/data/data_08-09.dta",replace 

* load dta file directly
use "$myPath/data/data_08-09.dta",clear    
cap drop *_i

xtset dhcode year

* defining variables
gen gross_income = disposable_income
gen loan_payment_ratio = total_payment / gross_income
replace disposable_income = disposable_income - mortgage_payment - interest_payment
replace total_consumption = nondurables + durables
gen dtotCons = d.total_consumption /l.disposable_income
gen dgross_income = d.gross_income
gen ddisposable_income = d.disposable_income /l.disposable_income
gen dnondurables = d.nondurables /l.disposable_income
gen ddurables = d.durables /l.disposable_income
replace age = age - 43
gen age_square = age^2
gen hv_inc = (housing_value - l.housing_value)/l.disposable_income


*keeping households with housing loan expenditures both in 2008 and 2009 
gen indi = 0
replace indi = 1 if total_payment != 0
bysort dhcode: egen indis = sum(indi)
keep if indis == 2

xtset dhcode year
gen _temp = d.mortgage_payment
bys dhcode: egen mortgage_payment_diff_i = max(_temp)
drop _temp

*trimming
gen trim = 0
*exclude households with investment income
replace trim = 1 if invest2 > 0
* exclude households who have business income
replace trim = 1 if business != 0


forval yy = 2008 / 2009 {
    foreach var of varlist loan_payment_ratio mortgage_payment_diff_i gross_income med_expense {
		su `var' if year == `yy', d
		replace trim = 1 if (`var' < r(p1) | `var' > r(p99)) & year == `yy'
		
		
	}
}

keep if trim == 0

* balance panel
bysort dhcode: keep if _N == 2


xtset dhcode year
gen ndconsShare2008 = nondurable / total_consumption if year == 2008
replace ndconsShare2008 = l.ndconsShare2008 if year == 2009


* make instrument
gen interest_ratio = interest_payment / total_payment if interest_payment != 0
bys year: egen interest_ratio_mean = mean(interest_ratio)
gen interest_payment_nozero = interest_payment if interest_payment != 0
bysort year: egen interest_payment_ave = mean(interest_payment_nozero)
bysort year: egen gross_income_ave = mean(gross_income)
xtset dhcode year

xtset dhcode year
gen dy = l.loan_payment_ratio


save "$myPath/data/estimation_sample",replace







